# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1alpha1/allocation_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__pb2
from nebius.api.nebius.vpc.v1alpha1 import allocation_pb2 as nebius_dot_vpc_dot_v1alpha1_dot_allocation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,nebius/vpc/v1alpha1/allocation_service.proto\x12\x13nebius.vpc.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a&nebius/common/v1alpha1/operation.proto\x1a$nebius/vpc/v1alpha1/allocation.proto\".\n\x14GetAllocationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"]\n\x1aGetAllocationByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"\x91\x01\n\x16ListAllocationsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"x\n\x17ListAllocationsResponse\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32\x1f.nebius.vpc.v1alpha1.AllocationR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xe7\x02\n\x17\x43reateAllocationRequest\x12\x8a\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc9\x01\xbaH\xc5\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\xc8\x01\x01R\x08metadata\x12?\n\x04spec\x18\x02 \x01(\x0b\x32#.nebius.vpc.v1alpha1.AllocationSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xdc\x02\n\x17UpdateAllocationRequest\x12\x87\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc6\x01\xbaH\xc2\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')R\x08metadata\x12\x37\n\x04spec\x18\x02 \x01(\x0b\x32#.nebius.vpc.v1alpha1.AllocationSpecR\x04spec\"1\n\x17\x44\x65leteAllocationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xc1\x04\n\x11\x41llocationService\x12Q\n\x03Get\x12).nebius.vpc.v1alpha1.GetAllocationRequest\x1a\x1f.nebius.vpc.v1alpha1.Allocation\x12]\n\tGetByName\x12/.nebius.vpc.v1alpha1.GetAllocationByNameRequest\x1a\x1f.nebius.vpc.v1alpha1.Allocation\x12\x61\n\x04List\x12+.nebius.vpc.v1alpha1.ListAllocationsRequest\x1a,.nebius.vpc.v1alpha1.ListAllocationsResponse\x12Y\n\x06\x43reate\x12,.nebius.vpc.v1alpha1.CreateAllocationRequest\x1a!.nebius.common.v1alpha1.Operation\x12Y\n\x06Update\x12,.nebius.vpc.v1alpha1.UpdateAllocationRequest\x1a!.nebius.common.v1alpha1.Operation\x12Y\n\x06\x44\x65lete\x12,.nebius.vpc.v1alpha1.DeleteAllocationRequest\x1a!.nebius.common.v1alpha1.Operation\x1a\x06\xbaJ\x03vpcBi\n\x1a\x61i.nebius.pub.vpc.v1alpha1B\x16\x41llocationServiceProtoP\x01Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1alpha1.allocation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032ai.nebius.pub.vpc.v1alpha1B\026AllocationServiceProtoP\001Z1github.com/nebius/gosdk/proto/nebius/vpc/v1alpha1'
  _GETALLOCATIONREQUEST.fields_by_name['id']._options = None
  _GETALLOCATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETALLOCATIONBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETALLOCATIONBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETALLOCATIONBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETALLOCATIONBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTALLOCATIONSREQUEST.fields_by_name['parent_id']._options = None
  _LISTALLOCATIONSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _CREATEALLOCATIONREQUEST.fields_by_name['metadata']._options = None
  _CREATEALLOCATIONREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\305\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')\310\001\001'
  _CREATEALLOCATIONREQUEST.fields_by_name['spec']._options = None
  _CREATEALLOCATIONREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _UPDATEALLOCATIONREQUEST.fields_by_name['metadata']._options = None
  _UPDATEALLOCATIONREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\302\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')'
  _DELETEALLOCATIONREQUEST.fields_by_name['id']._options = None
  _DELETEALLOCATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _ALLOCATIONSERVICE._options = None
  _ALLOCATIONSERVICE._serialized_options = b'\272J\003vpc'
  _globals['_GETALLOCATIONREQUEST']._serialized_start=235
  _globals['_GETALLOCATIONREQUEST']._serialized_end=281
  _globals['_GETALLOCATIONBYNAMEREQUEST']._serialized_start=283
  _globals['_GETALLOCATIONBYNAMEREQUEST']._serialized_end=376
  _globals['_LISTALLOCATIONSREQUEST']._serialized_start=379
  _globals['_LISTALLOCATIONSREQUEST']._serialized_end=524
  _globals['_LISTALLOCATIONSRESPONSE']._serialized_start=526
  _globals['_LISTALLOCATIONSRESPONSE']._serialized_end=646
  _globals['_CREATEALLOCATIONREQUEST']._serialized_start=649
  _globals['_CREATEALLOCATIONREQUEST']._serialized_end=1008
  _globals['_UPDATEALLOCATIONREQUEST']._serialized_start=1011
  _globals['_UPDATEALLOCATIONREQUEST']._serialized_end=1359
  _globals['_DELETEALLOCATIONREQUEST']._serialized_start=1361
  _globals['_DELETEALLOCATIONREQUEST']._serialized_end=1410
  _globals['_ALLOCATIONSERVICE']._serialized_start=1413
  _globals['_ALLOCATIONSERVICE']._serialized_end=1990
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/postgresql/v1alpha1/cluster.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.msp.v1alpha1 import cluster_pb2 as nebius_dot_msp_dot_v1alpha1_dot_cluster__pb2
from nebius.api.nebius.msp.postgresql.v1alpha1.config import postgresql_pb2 as nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_config_dot_postgresql__pb2
from nebius.api.nebius.msp.postgresql.v1alpha1 import template_pb2 as nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_template__pb2
from nebius.api.nebius.msp.v1alpha1.resource import template_pb2 as nebius_dot_msp_dot_v1alpha1_dot_resource_dot_template__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,nebius/msp/postgresql/v1alpha1/cluster.proto\x12\x1enebius.msp.postgresql.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a!nebius/msp/v1alpha1/cluster.proto\x1a\x36nebius/msp/postgresql/v1alpha1/config/postgresql.proto\x1a-nebius/msp/postgresql/v1alpha1/template.proto\x1a+nebius/msp/v1alpha1/resource/template.proto\x1a\x18nebius/annotations.proto\"\xe7\x01\n\x07\x43luster\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12G\n\x04spec\x18\x02 \x01(\x0b\x32+.nebius.msp.postgresql.v1alpha1.ClusterSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12K\n\x06status\x18\x03 \x01(\x0b\x32-.nebius.msp.postgresql.v1alpha1.ClusterStatusB\x04\xbaJ\x01\x05R\x06status\"\x91\x02\n\x16\x43onnectionPoolerConfig\x12\x65\n\x0cpooling_mode\x18\x01 \x01(\x0e\x32\x42.nebius.msp.postgresql.v1alpha1.ConnectionPoolerConfig.PoolingModeR\x0bpoolingMode\x12\x33\n\rmax_pool_size\x18\x02 \x01(\x03\x42\n\xbaH\x07\"\x05\x18\x80\x64(\x05H\x00R\x0bmaxPoolSize\x88\x01\x01\"I\n\x0bPoolingMode\x12\x1c\n\x18POOLING_MODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07SESSION\x10\x01\x12\x0f\n\x0bTRANSACTION\x10\x02\x42\x10\n\x0e_max_pool_size\"\xd3\x02\n\x0b\x43lusterSpec\x12.\n\x0b\x64\x65scription\x18\x01 \x01(\tB\x0c\xbaH\x05r\x03\x18\x80\x02\xbaJ\x01\x02R\x0b\x64\x65scription\x12)\n\nnetwork_id\x18\x06 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tnetworkId\x12J\n\x06\x63onfig\x18\x03 \x01(\x0b\x32*.nebius.msp.postgresql.v1alpha1.ConfigSpecB\x06\xbaH\x03\xc8\x01\x01R\x06\x63onfig\x12S\n\tbootstrap\x18\x04 \x01(\x0b\x32-.nebius.msp.postgresql.v1alpha1.BootstrapSpecB\x06\xbaH\x03\xc8\x01\x01R\tbootstrap\x12H\n\x06\x62\x61\x63kup\x18\x05 \x01(\x0b\x32*.nebius.msp.postgresql.v1alpha1.BackupSpecB\x04\xbaJ\x01\x02R\x06\x62\x61\x63kup\"\xc1\x02\n\rClusterStatus\x12>\n\x05phase\x18\x01 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.PhaseR\x05phase\x12>\n\x05state\x18\x02 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.StateR\x05state\x12R\n\x0epreset_details\x18\x04 \x01(\x0b\x32+.nebius.msp.v1alpha1.resource.PresetDetailsR\rpresetDetails\x12\\\n\x14\x63onnection_endpoints\x18\x05 \x01(\x0b\x32).nebius.msp.postgresql.v1alpha1.EndpointsR\x13\x63onnectionEndpoints\"\xd3\x01\n\tEndpoints\x12\x32\n\x12private_read_write\x18\x01 \x01(\tB\x04\xbaJ\x01\x05R\x10privateReadWrite\x12\x30\n\x11private_read_only\x18\x02 \x01(\tB\x04\xbaJ\x01\x05R\x0fprivateReadOnly\x12\x30\n\x11public_read_write\x18\x03 \x01(\tB\x04\xbaJ\x01\x05R\x0fpublicReadWrite\x12.\n\x10public_read_only\x18\x04 \x01(\tB\x04\xbaJ\x01\x05R\x0epublicReadOnly\"\x85\x03\n\nConfigSpec\x12$\n\x07version\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x07version\x12[\n\rpooler_config\x18\x02 \x01(\x0b\x32\x36.nebius.msp.postgresql.v1alpha1.ConnectionPoolerConfigR\x0cpoolerConfig\x12m\n\x14postgresql_config_16\x18\x04 \x01(\x0b\x32\x39.nebius.msp.postgresql.v1alpha1.config.PostgresqlConfig16H\x00R\x12postgresqlConfig16\x12#\n\rpublic_access\x18\x05 \x01(\x08R\x0cpublicAccess\x12P\n\x08template\x18\x07 \x01(\x0b\x32,.nebius.msp.postgresql.v1alpha1.TemplateSpecB\x06\xbaH\x03\xc8\x01\x01R\x08templateB\x08\n\x06\x63onfigJ\x04\x08\x03\x10\x04\"\x81\x06\n\rBootstrapSpec\x12\xde\x02\n\tuser_name\x18\x01 \x01(\tB\xc0\x02\xbaH\xb8\x02\xba\x01V\n\x14user_name.min_length\x12-User name must be at least 1 characters long.\x1a\x0fsize(this) >= 1\xba\x01R\n\x14user_name.max_length\x12(User name must not exceed 63 characters.\x1a\x10size(this) <= 63\xba\x01\x83\x01\n\x11user_name.pattern\x12@User name must match the pattern: \'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\'\x1a,this.matches(\'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\')\xc8\x01\x01\xbaJ\x01\x02R\x08userName\x12,\n\ruser_password\x18\x02 \x01(\tB\x07\xbaJ\x01\x04\xc0J\x01R\x0cuserPassword\x12\xe0\x02\n\x07\x64\x62_name\x18\x03 \x01(\tB\xc6\x02\xbaH\xbe\x02\xba\x01X\n\x12\x64\x62_name.min_length\x12\x31\x44\x61tabase name must be at least 1 characters long.\x1a\x0fsize(this) >= 1\xba\x01T\n\x12\x64\x62_name.max_length\x12,Database name must not exceed 63 characters.\x1a\x10size(this) <= 63\xba\x01\x85\x01\n\x0f\x64\x62_name.pattern\x12\x44\x44\x61tabase name must match the pattern: \'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\'\x1a,this.matches(\'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\')\xc8\x01\x01\xbaJ\x01\x02R\x06\x64\x62Name\"g\n\nBackupSpec\x12.\n\x13\x62\x61\x63kup_window_start\x18\x01 \x01(\tR\x11\x62\x61\x63kupWindowStart\x12)\n\x10retention_policy\x18\x02 \x01(\tR\x0fretentionPolicyBu\n%ai.nebius.pub.msp.postgresql.v1alpha1B\x0c\x43lusterProtoP\x01Z<github.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.postgresql.v1alpha1.cluster_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%ai.nebius.pub.msp.postgresql.v1alpha1B\014ClusterProtoP\001Z<github.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1'
  _CLUSTER.fields_by_name['metadata']._options = None
  _CLUSTER.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTER.fields_by_name['spec']._options = None
  _CLUSTER.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTER.fields_by_name['status']._options = None
  _CLUSTER.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _CONNECTIONPOOLERCONFIG.fields_by_name['max_pool_size']._options = None
  _CONNECTIONPOOLERCONFIG.fields_by_name['max_pool_size']._serialized_options = b'\272H\007\"\005\030\200d(\005'
  _CLUSTERSPEC.fields_by_name['description']._options = None
  _CLUSTERSPEC.fields_by_name['description']._serialized_options = b'\272H\005r\003\030\200\002\272J\001\002'
  _CLUSTERSPEC.fields_by_name['network_id']._options = None
  _CLUSTERSPEC.fields_by_name['network_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _CLUSTERSPEC.fields_by_name['config']._options = None
  _CLUSTERSPEC.fields_by_name['config']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTERSPEC.fields_by_name['bootstrap']._options = None
  _CLUSTERSPEC.fields_by_name['bootstrap']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTERSPEC.fields_by_name['backup']._options = None
  _CLUSTERSPEC.fields_by_name['backup']._serialized_options = b'\272J\001\002'
  _ENDPOINTS.fields_by_name['private_read_write']._options = None
  _ENDPOINTS.fields_by_name['private_read_write']._serialized_options = b'\272J\001\005'
  _ENDPOINTS.fields_by_name['private_read_only']._options = None
  _ENDPOINTS.fields_by_name['private_read_only']._serialized_options = b'\272J\001\005'
  _ENDPOINTS.fields_by_name['public_read_write']._options = None
  _ENDPOINTS.fields_by_name['public_read_write']._serialized_options = b'\272J\001\005'
  _ENDPOINTS.fields_by_name['public_read_only']._options = None
  _ENDPOINTS.fields_by_name['public_read_only']._serialized_options = b'\272J\001\005'
  _CONFIGSPEC.fields_by_name['version']._options = None
  _CONFIGSPEC.fields_by_name['version']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _CONFIGSPEC.fields_by_name['template']._options = None
  _CONFIGSPEC.fields_by_name['template']._serialized_options = b'\272H\003\310\001\001'
  _BOOTSTRAPSPEC.fields_by_name['user_name']._options = None
  _BOOTSTRAPSPEC.fields_by_name['user_name']._serialized_options = b'\272H\270\002\272\001V\n\024user_name.min_length\022-User name must be at least 1 characters long.\032\017size(this) >= 1\272\001R\n\024user_name.max_length\022(User name must not exceed 63 characters.\032\020size(this) <= 63\272\001\203\001\n\021user_name.pattern\022@User name must match the pattern: \'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\'\032,this.matches(\'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\')\310\001\001\272J\001\002'
  _BOOTSTRAPSPEC.fields_by_name['user_password']._options = None
  _BOOTSTRAPSPEC.fields_by_name['user_password']._serialized_options = b'\272J\001\004\300J\001'
  _BOOTSTRAPSPEC.fields_by_name['db_name']._options = None
  _BOOTSTRAPSPEC.fields_by_name['db_name']._serialized_options = b'\272H\276\002\272\001X\n\022db_name.min_length\0221Database name must be at least 1 characters long.\032\017size(this) >= 1\272\001T\n\022db_name.max_length\022,Database name must not exceed 63 characters.\032\020size(this) <= 63\272\001\205\001\n\017db_name.pattern\022DDatabase name must match the pattern: \'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\'\032,this.matches(\'^[a-zA-Z0-9_][a-zA-Z0-9_-]*$\')\310\001\001\272J\001\002'
  _globals['_CLUSTER']._serialized_start=352
  _globals['_CLUSTER']._serialized_end=583
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_start=586
  _globals['_CONNECTIONPOOLERCONFIG']._serialized_end=859
  _globals['_CONNECTIONPOOLERCONFIG_POOLINGMODE']._serialized_start=768
  _globals['_CONNECTIONPOOLERCONFIG_POOLINGMODE']._serialized_end=841
  _globals['_CLUSTERSPEC']._serialized_start=862
  _globals['_CLUSTERSPEC']._serialized_end=1201
  _globals['_CLUSTERSTATUS']._serialized_start=1204
  _globals['_CLUSTERSTATUS']._serialized_end=1525
  _globals['_ENDPOINTS']._serialized_start=1528
  _globals['_ENDPOINTS']._serialized_end=1739
  _globals['_CONFIGSPEC']._serialized_start=1742
  _globals['_CONFIGSPEC']._serialized_end=2131
  _globals['_BOOTSTRAPSPEC']._serialized_start=2134
  _globals['_BOOTSTRAPSPEC']._serialized_end=2903
  _globals['_BACKUPSPEC']._serialized_start=2905
  _globals['_BACKUPSPEC']._serialized_end=3008
# @@protoc_insertion_point(module_scope)



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Network(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: NetworkSpec
    status: NetworkStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[NetworkSpec, _Mapping]] = ..., status: _Optional[_Union[NetworkStatus, _Mapping]] = ...) -> None: ...

class NetworkSpec(_message.Message):
    __slots__ = ["pools"]
    POOLS_FIELD_NUMBER: _ClassVar[int]
    pools: _containers.RepeatedCompositeFieldContainer[NetworkPool]
    def __init__(self, pools: _Optional[_Iterable[_Union[NetworkPool, _Mapping]]] = ...) -> None: ...

class NetworkPool(_message.Message):
    __slots__ = ["pool_id"]
    POOL_ID_FIELD_NUMBER: _ClassVar[int]
    pool_id: str
    def __init__(self, pool_id: _Optional[str] = ...) -> None: ...

class NetworkStatus(_message.Message):
    __slots__ = ["state", "scope_id"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATE_UNSPECIFIED: _ClassVar[NetworkStatus.State]
        CREATING: _ClassVar[NetworkStatus.State]
        READY: _ClassVar[NetworkStatus.State]
        DELETING: _ClassVar[NetworkStatus.State]
    STATE_UNSPECIFIED: NetworkStatus.State
    CREATING: NetworkStatus.State
    READY: NetworkStatus.State
    DELETING: NetworkStatus.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    SCOPE_ID_FIELD_NUMBER: _ClassVar[int]
    state: NetworkStatus.State
    scope_id: str
    def __init__(self, state: _Optional[_Union[NetworkStatus.State, str]] = ..., scope_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/common/v1/operation_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/common/v1/operation_service.proto\x12\x10nebius.common.v1\x1a\x1b\x62uf/validate/validate.proto\x1a nebius/common/v1/operation.proto\"-\n\x13GetOperationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"|\n\x15ListOperationsRequest\x12\'\n\x0bresource_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\nresourceId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"}\n\x16ListOperationsResponse\x12;\n\noperations\x18\x01 \x03(\x0b\x32\x1b.nebius.common.v1.OperationR\noperations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xb8\x01\n\x10OperationService\x12I\n\x03Get\x12%.nebius.common.v1.GetOperationRequest\x1a\x1b.nebius.common.v1.Operation\x12Y\n\x04List\x12\'.nebius.common.v1.ListOperationsRequest\x1a(.nebius.common.v1.ListOperationsResponseBb\n\x17\x61i.nebius.pub.common.v1B\x15OperationServiceProtoP\x01Z.github.com/nebius/gosdk/proto/nebius/common/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.common.v1.operation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027ai.nebius.pub.common.v1B\025OperationServiceProtoP\001Z.github.com/nebius/gosdk/proto/nebius/common/v1'
  _GETOPERATIONREQUEST.fields_by_name['id']._options = None
  _GETOPERATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTOPERATIONSREQUEST.fields_by_name['resource_id']._options = None
  _LISTOPERATIONSREQUEST.fields_by_name['resource_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETOPERATIONREQUEST']._serialized_start=125
  _globals['_GETOPERATIONREQUEST']._serialized_end=170
  _globals['_LISTOPERATIONSREQUEST']._serialized_start=172
  _globals['_LISTOPERATIONSREQUEST']._serialized_end=296
  _globals['_LISTOPERATIONSRESPONSE']._serialized_start=298
  _globals['_LISTOPERATIONSRESPONSE']._serialized_end=423
  _globals['_OPERATIONSERVICE']._serialized_start=426
  _globals['_OPERATIONSERVICE']._serialized_end=610
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import auth_public_key_pb2 as nebius_dot_iam_dot_v1_dot_auth__public__key__pb2
from nebius.api.nebius.iam.v1 import auth_public_key_service_pb2 as nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2


class AuthPublicKeyServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Create',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.CreateAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Get = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Get',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.GetAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__pb2.AuthPublicKey.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/List',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.FromString,
                )
        self.ListByAccount = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/ListByAccount',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyByAccountRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Update',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.UpdateAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Activate = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Activate',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ActivateAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Deactivate = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Deactivate',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeactivateAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.iam.v1.AuthPublicKeyService/Delete',
                request_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeleteAuthPublicKeyRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class AuthPublicKeyServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListByAccount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Activate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Deactivate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AuthPublicKeyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.CreateAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.GetAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__pb2.AuthPublicKey.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.SerializeToString,
            ),
            'ListByAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.ListByAccount,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyByAccountRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.UpdateAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Activate': grpc.unary_unary_rpc_method_handler(
                    servicer.Activate,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ActivateAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Deactivate': grpc.unary_unary_rpc_method_handler(
                    servicer.Deactivate,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeactivateAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeleteAuthPublicKeyRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.iam.v1.AuthPublicKeyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AuthPublicKeyService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Create',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.CreateAuthPublicKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Get',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.GetAuthPublicKeyRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_auth__public__key__pb2.AuthPublicKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/List',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListByAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/ListByAccount',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyByAccountRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ListAuthPublicKeyResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Update',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.UpdateAuthPublicKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Activate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Activate',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.ActivateAuthPublicKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Deactivate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Deactivate',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeactivateAuthPublicKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.AuthPublicKeyService/Delete',
            nebius_dot_iam_dot_v1_dot_auth__public__key__service__pb2.DeleteAuthPublicKeyRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/route.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19nebius/vpc/v1/route.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\"\xa9\x01\n\x05Route\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12,\n\x04spec\x18\x02 \x01(\x0b\x32\x18.nebius.vpc.v1.RouteSpecR\x04spec\x12\x32\n\x06status\x18\x03 \x01(\x0b\x32\x1a.nebius.vpc.v1.RouteStatusR\x06status\"\xbb\x01\n\tRouteSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12M\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32\x1f.nebius.vpc.v1.DestinationMatchB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x0b\x64\x65stination\x12=\n\x08next_hop\x18\x03 \x01(\x0b\x32\x16.nebius.vpc.v1.NextHopB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x07nextHop\"\xd4\x01\n\x10\x44\x65stinationMatch\x12\xbf\x01\n\x04\x63idr\x18\x01 \x01(\tB\xaa\x01\xbaH\xa2\x01\xba\x01\x9b\x01\n\x11string.valid_cidr\x12\x33\x64\x65stination.cidr must be a valid and specified CIDR\x1aQthis.matches(\'^([0-9]{1,3}\\\\.){3}[0-9]{1,3}/[0-9]+$\') && this.isIpPrefix(4, true)\xc8\x01\x01\xbaJ\x01\x02R\x04\x63idr\"\x98\x01\n\x07NextHop\x12\x42\n\nallocation\x18\x01 \x01(\x0b\x32 .nebius.vpc.v1.AllocationNextHopH\x00R\nallocation\x12\x36\n\x16\x64\x65\x66\x61ult_egress_gateway\x18\x02 \x01(\x08H\x00R\x14\x64\x65\x66\x61ultEgressGatewayB\x11\n\x08next_hop\x12\x05\xbaH\x02\x08\x01\"+\n\x11\x41llocationNextHop\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xa8\x01\n\x0bRouteStatus\x12\x36\n\x05state\x18\x01 \x01(\x0e\x32 .nebius.vpc.v1.RouteStatus.StateR\x05state\x12\x36\n\x08next_hop\x18\x02 \x01(\x0b\x32\x1b.nebius.vpc.v1.NextHopStateR\x07nextHop\")\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05READY\x10\n\"\xc5\x01\n\x0cNextHopState\x12G\n\nallocation\x18\x01 \x01(\x0b\x32%.nebius.vpc.v1.AllocationNextHopStateH\x00R\nallocation\x12`\n\x16\x64\x65\x66\x61ult_egress_gateway\x18\x02 \x01(\x0b\x32(.nebius.vpc.v1.DefaultEgressGatewayStateH\x00R\x14\x64\x65\x66\x61ultEgressGatewayB\n\n\x08next_hop\",\n\x16\x41llocationNextHopState\x12\x12\n\x04\x63idr\x18\x01 \x01(\tR\x04\x63idr\"\x1b\n\x19\x44\x65\x66\x61ultEgressGatewayStateBQ\n\x14\x61i.nebius.pub.vpc.v1B\nRouteProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.route_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\nRouteProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _ROUTESPEC.fields_by_name['destination']._options = None
  _ROUTESPEC.fields_by_name['destination']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _ROUTESPEC.fields_by_name['next_hop']._options = None
  _ROUTESPEC.fields_by_name['next_hop']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _DESTINATIONMATCH.fields_by_name['cidr']._options = None
  _DESTINATIONMATCH.fields_by_name['cidr']._serialized_options = b'\272H\242\001\272\001\233\001\n\021string.valid_cidr\0223destination.cidr must be a valid and specified CIDR\032Qthis.matches(\'^([0-9]{1,3}\\\\.){3}[0-9]{1,3}/[0-9]+$\') && this.isIpPrefix(4, true)\310\001\001\272J\001\002'
  _NEXTHOP.oneofs_by_name['next_hop']._options = None
  _NEXTHOP.oneofs_by_name['next_hop']._serialized_options = b'\272H\002\010\001'
  _ALLOCATIONNEXTHOP.fields_by_name['id']._options = None
  _ALLOCATIONNEXTHOP.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_ROUTE']._serialized_start=133
  _globals['_ROUTE']._serialized_end=302
  _globals['_ROUTESPEC']._serialized_start=305
  _globals['_ROUTESPEC']._serialized_end=492
  _globals['_DESTINATIONMATCH']._serialized_start=495
  _globals['_DESTINATIONMATCH']._serialized_end=707
  _globals['_NEXTHOP']._serialized_start=710
  _globals['_NEXTHOP']._serialized_end=862
  _globals['_ALLOCATIONNEXTHOP']._serialized_start=864
  _globals['_ALLOCATIONNEXTHOP']._serialized_end=907
  _globals['_ROUTESTATUS']._serialized_start=910
  _globals['_ROUTESTATUS']._serialized_end=1078
  _globals['_ROUTESTATUS_STATE']._serialized_start=1037
  _globals['_ROUTESTATUS_STATE']._serialized_end=1078
  _globals['_NEXTHOPSTATE']._serialized_start=1081
  _globals['_NEXTHOPSTATE']._serialized_end=1278
  _globals['_ALLOCATIONNEXTHOPSTATE']._serialized_start=1280
  _globals['_ALLOCATIONNEXTHOPSTATE']._serialized_end=1324
  _globals['_DEFAULTEGRESSGATEWAYSTATE']._serialized_start=1326
  _globals['_DEFAULTEGRESSGATEWAYSTATE']._serialized_end=1353
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/billing/v1alpha1/calculator_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.billing.v1alpha1 import calculator_pb2 as nebius_dot_billing_dot_v1alpha1_dot_calculator__pb2
from nebius.api.nebius.billing.v1alpha1 import offer_type_pb2 as nebius_dot_billing_dot_v1alpha1_dot_offer__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0nebius/billing/v1alpha1/calculator_service.proto\x12\x17nebius.billing.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a(nebius/billing/v1alpha1/calculator.proto\x1a(nebius/billing/v1alpha1/offer_type.proto\"\xaa\x01\n\x0f\x45stimateRequest\x12R\n\rresource_spec\x18\x01 \x01(\x0b\x32%.nebius.billing.v1alpha1.ResourceSpecB\x06\xbaH\x03\xc8\x01\x01R\x0cresourceSpec\x12\x43\n\x0boffer_types\x18\n \x03(\x0e\x32\".nebius.billing.v1alpha1.OfferTypeR\nofferTypes\"\xae\x01\n\x10\x45stimateResponse\x12K\n\x0bhourly_cost\x18\n \x01(\x0b\x32*.nebius.billing.v1alpha1.ResourceGroupCostR\nhourlyCost\x12M\n\x0cmonthly_cost\x18\x14 \x01(\x0b\x32*.nebius.billing.v1alpha1.ResourceGroupCostR\x0bmonthlyCost\"\xb1\x01\n\x14\x45stimateBatchRequest\x12T\n\x0eresource_specs\x18\x01 \x03(\x0b\x32%.nebius.billing.v1alpha1.ResourceSpecB\x06\xbaH\x03\xc8\x01\x01R\rresourceSpecs\x12\x43\n\x0boffer_types\x18\n \x03(\x0e\x32\".nebius.billing.v1alpha1.OfferTypeR\nofferTypes\"\xb3\x01\n\x15\x45stimateBatchResponse\x12K\n\x0bhourly_cost\x18\n \x01(\x0b\x32*.nebius.billing.v1alpha1.ResourceGroupCostR\nhourlyCost\x12M\n\x0cmonthly_cost\x18\x14 \x01(\x0b\x32*.nebius.billing.v1alpha1.ResourceGroupCostR\x0bmonthlyCost2\x8a\x02\n\x11\x43\x61lculatorService\x12_\n\x08\x45stimate\x12(.nebius.billing.v1alpha1.EstimateRequest\x1a).nebius.billing.v1alpha1.EstimateResponse\x12n\n\rEstimateBatch\x12-.nebius.billing.v1alpha1.EstimateBatchRequest\x1a..nebius.billing.v1alpha1.EstimateBatchResponse\x1a$\xbaJ!api.calculator.billing-data-planeBq\n\x1e\x61i.nebius.pub.billing.v1alpha1B\x16\x43\x61lculatorServiceProtoP\x01Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.billing.v1alpha1.calculator_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036ai.nebius.pub.billing.v1alpha1B\026CalculatorServiceProtoP\001Z5github.com/nebius/gosdk/proto/nebius/billing/v1alpha1'
  _ESTIMATEREQUEST.fields_by_name['resource_spec']._options = None
  _ESTIMATEREQUEST.fields_by_name['resource_spec']._serialized_options = b'\272H\003\310\001\001'
  _ESTIMATEBATCHREQUEST.fields_by_name['resource_specs']._options = None
  _ESTIMATEBATCHREQUEST.fields_by_name['resource_specs']._serialized_options = b'\272H\003\310\001\001'
  _CALCULATORSERVICE._options = None
  _CALCULATORSERVICE._serialized_options = b'\272J!api.calculator.billing-data-plane'
  _globals['_ESTIMATEREQUEST']._serialized_start=217
  _globals['_ESTIMATEREQUEST']._serialized_end=387
  _globals['_ESTIMATERESPONSE']._serialized_start=390
  _globals['_ESTIMATERESPONSE']._serialized_end=564
  _globals['_ESTIMATEBATCHREQUEST']._serialized_start=567
  _globals['_ESTIMATEBATCHREQUEST']._serialized_end=744
  _globals['_ESTIMATEBATCHRESPONSE']._serialized_start=747
  _globals['_ESTIMATEBATCHRESPONSE']._serialized_end=926
  _globals['_CALCULATORSERVICE']._serialized_start=929
  _globals['_CALCULATORSERVICE']._serialized_end=1195
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/audit/v2/audit_event_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.audit.v2 import audit_event_pb2 as nebius_dot_audit_dot_v2_dot_audit__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/audit/v2/audit_event_service.proto\x12\x0fnebius.audit.v2\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x18nebius/annotations.proto\x1a!nebius/audit/v2/audit_event.proto\"\x91\x02\n\x15ListAuditEventRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\'\n\tpage_size\x18\x02 \x01(\x03\x42\n\xbaH\x07\"\x05\x18\xf4\x03(\x00R\x08pageSize\x12\x38\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x05start\x12\x34\n\x03\x65nd\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x06\xbaH\x03\xc8\x01\x01R\x03\x65nd\x12\x1d\n\npage_token\x18\x05 \x01(\tR\tpageToken\x12\x1b\n\x06\x66ilter\x18\x06 \x01(\tB\x03\xc0J\x01R\x06\x66ilter\"s\n\x16ListAuditEventResponse\x12\x31\n\x05items\x18\x01 \x03(\x0b\x32\x1b.nebius.audit.v2.AuditEventR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2v\n\x11\x41uditEventService\x12W\n\x04List\x12&.nebius.audit.v2.ListAuditEventRequest\x1a\'.nebius.audit.v2.ListAuditEventResponse\x1a\x08\xbaJ\x05\x61uditBa\n\x16\x61i.nebius.pub.audit.v2B\x16\x41uditEventServiceProtoP\x01Z-github.com/nebius/gosdk/proto/nebius/audit/v2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.audit.v2.audit_event_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ai.nebius.pub.audit.v2B\026AuditEventServiceProtoP\001Z-github.com/nebius/gosdk/proto/nebius/audit/v2'
  _LISTAUDITEVENTREQUEST.fields_by_name['parent_id']._options = None
  _LISTAUDITEVENTREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTAUDITEVENTREQUEST.fields_by_name['page_size']._options = None
  _LISTAUDITEVENTREQUEST.fields_by_name['page_size']._serialized_options = b'\272H\007\"\005\030\364\003(\000'
  _LISTAUDITEVENTREQUEST.fields_by_name['start']._options = None
  _LISTAUDITEVENTREQUEST.fields_by_name['start']._serialized_options = b'\272H\003\310\001\001'
  _LISTAUDITEVENTREQUEST.fields_by_name['end']._options = None
  _LISTAUDITEVENTREQUEST.fields_by_name['end']._serialized_options = b'\272H\003\310\001\001'
  _LISTAUDITEVENTREQUEST.fields_by_name['filter']._options = None
  _LISTAUDITEVENTREQUEST.fields_by_name['filter']._serialized_options = b'\300J\001'
  _AUDITEVENTSERVICE._options = None
  _AUDITEVENTSERVICE._serialized_options = b'\272J\005audit'
  _globals['_LISTAUDITEVENTREQUEST']._serialized_start=186
  _globals['_LISTAUDITEVENTREQUEST']._serialized_end=459
  _globals['_LISTAUDITEVENTRESPONSE']._serialized_start=461
  _globals['_LISTAUDITEVENTRESPONSE']._serialized_end=576
  _globals['_AUDITEVENTSERVICE']._serialized_start=578
  _globals['_AUDITEVENTSERVICE']._serialized_end=696
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import group_membership_pb2 as nebius_dot_iam_dot_v1_dot_group__membership__pb2
from nebius.api.nebius.iam.v1 import group_membership_service_pb2 as nebius_dot_iam_dot_v1_dot_group__membership__service__pb2


class GroupMembershipServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/nebius.iam.v1.GroupMembershipService/Create',
                request_serializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.CreateGroupMembershipRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Get = channel.unary_unary(
                '/nebius.iam.v1.GroupMembershipService/Get',
                request_serializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.GetGroupMembershipRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__pb2.GroupMembership.FromString,
                )
        self.GetWithAttributes = channel.unary_unary(
                '/nebius.iam.v1.GroupMembershipService/GetWithAttributes',
                request_serializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.GetGroupMembershipRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__pb2.GroupMembershipWithAttributes.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.iam.v1.GroupMembershipService/Delete',
                request_serializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.DeleteGroupMembershipRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.ListMembers = channel.unary_unary(
                '/nebius.iam.v1.GroupMembershipService/ListMembers',
                request_serializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsResponse.FromString,
                )
        self.ListMembersWithAttributes = channel.unary_unary(
                '/nebius.iam.v1.GroupMembershipService/ListMembersWithAttributes',
                request_serializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsWithAttributesResponse.FromString,
                )
        self.ListMemberOf = channel.unary_unary(
                '/nebius.iam.v1.GroupMembershipService/ListMemberOf',
                request_serializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListMemberOfRequest.SerializeToString,
                response_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListMemberOfResponse.FromString,
                )


class GroupMembershipServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetWithAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMembersWithAttributes(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMemberOf(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GroupMembershipServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.CreateGroupMembershipRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.GetGroupMembershipRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_group__membership__pb2.GroupMembership.SerializeToString,
            ),
            'GetWithAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.GetWithAttributes,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.GetGroupMembershipRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_group__membership__pb2.GroupMembershipWithAttributes.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.DeleteGroupMembershipRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListMembers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMembers,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsResponse.SerializeToString,
            ),
            'ListMembersWithAttributes': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMembersWithAttributes,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsWithAttributesResponse.SerializeToString,
            ),
            'ListMemberOf': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMemberOf,
                    request_deserializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListMemberOfRequest.FromString,
                    response_serializer=nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListMemberOfResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.iam.v1.GroupMembershipService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class GroupMembershipService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.GroupMembershipService/Create',
            nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.CreateGroupMembershipRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.GroupMembershipService/Get',
            nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.GetGroupMembershipRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_group__membership__pb2.GroupMembership.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetWithAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.GroupMembershipService/GetWithAttributes',
            nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.GetGroupMembershipRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_group__membership__pb2.GroupMembershipWithAttributes.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.GroupMembershipService/Delete',
            nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.DeleteGroupMembershipRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.GroupMembershipService/ListMembers',
            nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMembersWithAttributes(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.GroupMembershipService/ListMembersWithAttributes',
            nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListGroupMembershipsWithAttributesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListMemberOf(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.iam.v1.GroupMembershipService/ListMemberOf',
            nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListMemberOfRequest.SerializeToString,
            nebius_dot_iam_dot_v1_dot_group__membership__service__pb2.ListMemberOfResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.vpc.v1 import allocation_pb2 as nebius_dot_vpc_dot_v1_dot_allocation__pb2
from nebius.api.nebius.vpc.v1 import allocation_service_pb2 as nebius_dot_vpc_dot_v1_dot_allocation__service__pb2


class AllocationServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/nebius.vpc.v1.AllocationService/Get',
                request_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.GetAllocationRequest.SerializeToString,
                response_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__pb2.Allocation.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/nebius.vpc.v1.AllocationService/GetByName',
                request_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.GetAllocationByNameRequest.SerializeToString,
                response_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__pb2.Allocation.FromString,
                )
        self.List = channel.unary_unary(
                '/nebius.vpc.v1.AllocationService/List',
                request_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsRequest.SerializeToString,
                response_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsResponse.FromString,
                )
        self.ListByPool = channel.unary_unary(
                '/nebius.vpc.v1.AllocationService/ListByPool',
                request_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsByPoolRequest.SerializeToString,
                response_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsResponse.FromString,
                )
        self.ListBySubnet = channel.unary_unary(
                '/nebius.vpc.v1.AllocationService/ListBySubnet',
                request_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsBySubnetRequest.SerializeToString,
                response_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/nebius.vpc.v1.AllocationService/Create',
                request_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.CreateAllocationRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/nebius.vpc.v1.AllocationService/Update',
                request_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.UpdateAllocationRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/nebius.vpc.v1.AllocationService/Delete',
                request_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.DeleteAllocationRequest.SerializeToString,
                response_deserializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
                )


class AllocationServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListByPool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBySubnet(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AllocationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.GetAllocationRequest.FromString,
                    response_serializer=nebius_dot_vpc_dot_v1_dot_allocation__pb2.Allocation.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.GetAllocationByNameRequest.FromString,
                    response_serializer=nebius_dot_vpc_dot_v1_dot_allocation__pb2.Allocation.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsRequest.FromString,
                    response_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsResponse.SerializeToString,
            ),
            'ListByPool': grpc.unary_unary_rpc_method_handler(
                    servicer.ListByPool,
                    request_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsByPoolRequest.FromString,
                    response_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsResponse.SerializeToString,
            ),
            'ListBySubnet': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBySubnet,
                    request_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsBySubnetRequest.FromString,
                    response_serializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.CreateAllocationRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.UpdateAllocationRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.DeleteAllocationRequest.FromString,
                    response_serializer=nebius_dot_common_dot_v1_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'nebius.vpc.v1.AllocationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AllocationService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.vpc.v1.AllocationService/Get',
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.GetAllocationRequest.SerializeToString,
            nebius_dot_vpc_dot_v1_dot_allocation__pb2.Allocation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.vpc.v1.AllocationService/GetByName',
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.GetAllocationByNameRequest.SerializeToString,
            nebius_dot_vpc_dot_v1_dot_allocation__pb2.Allocation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.vpc.v1.AllocationService/List',
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsRequest.SerializeToString,
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListByPool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.vpc.v1.AllocationService/ListByPool',
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsByPoolRequest.SerializeToString,
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListBySubnet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.vpc.v1.AllocationService/ListBySubnet',
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsBySubnetRequest.SerializeToString,
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.ListAllocationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.vpc.v1.AllocationService/Create',
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.CreateAllocationRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.vpc.v1.AllocationService/Update',
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.UpdateAllocationRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/nebius.vpc.v1.AllocationService/Delete',
            nebius_dot_vpc_dot_v1_dot_allocation__service__pb2.DeleteAllocationRequest.SerializeToString,
            nebius_dot_common_dot_v1_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/compute/v1/network_interface.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)nebius/compute/v1/network_interface.proto\x12\x11nebius.compute.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\"\xd1\x02\n\x14NetworkInterfaceSpec\x12\'\n\tsubnet_id\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\x08subnetId\x12:\n\x04name\x18\x02 \x01(\tB&\xbaH\x1f\xc8\x01\x01r\x1a\x10\x01\x18<2\x14^[0-9a-z][0-9a-z-]*$\xbaJ\x01\x02R\x04name\x12H\n\nip_address\x18\x03 \x01(\x0b\x32\x1c.nebius.compute.v1.IPAddressB\x0b\xbaH\x03\xc8\x01\x01\xbaJ\x02\x06\x02R\tipAddress\x12T\n\x11public_ip_address\x18\x04 \x01(\x0b\x32\".nebius.compute.v1.PublicIPAddressB\x04\xbaJ\x01\x06R\x0fpublicIpAddress\x12\x34\n\x07\x61liases\x18\x06 \x03(\x0b\x32\x1a.nebius.compute.v1.IPAliasR\x07\x61liases\"0\n\tIPAddress\x12#\n\rallocation_id\x18\x01 \x01(\tR\x0c\x61llocationId\"^\n\x0fPublicIPAddress\x12%\n\rallocation_id\x18\x01 \x01(\tH\x00R\x0c\x61llocationId\x12\x16\n\x06static\x18\x03 \x01(\x08R\x06staticB\x0c\n\nallocation\"6\n\x07IPAlias\x12+\n\rallocation_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0c\x61llocationId\"\xce\x02\n\x16NetworkInterfaceStatus\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x41\n\nip_address\x18\x03 \x01(\x0b\x32\".nebius.compute.v1.IPAddressStatusR\tipAddress\x12T\n\x11public_ip_address\x18\x04 \x01(\x0b\x32(.nebius.compute.v1.PublicIPAddressStatusR\x0fpublicIpAddress\x12<\n\x07\x61liases\x18\x06 \x01(\x0b\x32\".nebius.compute.v1.IPAliasesStatusR\x07\x61liases\x12\x1f\n\x0bmac_address\x18\x07 \x01(\tR\nmacAddress\x12\x12\n\x04\x66qdn\x18\t \x01(\tR\x04\x66qdn\"P\n\x0fIPAddressStatus\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12#\n\rallocation_id\x18\x02 \x01(\tR\x0c\x61llocationId\"n\n\x15PublicIPAddressStatus\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12#\n\rallocation_id\x18\x02 \x01(\tR\x0c\x61llocationId\x12\x16\n\x06static\x18\x03 \x01(\x08R\x06static\"\'\n\x0fIPAliasesStatus\x12\x14\n\x05\x63idrs\x18\x02 \x03(\tR\x05\x63idrsBd\n\x18\x61i.nebius.pub.compute.v1B\x15NetworkInterfaceProtoP\x01Z/github.com/nebius/gosdk/proto/nebius/compute/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.compute.v1.network_interface_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030ai.nebius.pub.compute.v1B\025NetworkInterfaceProtoP\001Z/github.com/nebius/gosdk/proto/nebius/compute/v1'
  _NETWORKINTERFACESPEC.fields_by_name['subnet_id']._options = None
  _NETWORKINTERFACESPEC.fields_by_name['subnet_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _NETWORKINTERFACESPEC.fields_by_name['name']._options = None
  _NETWORKINTERFACESPEC.fields_by_name['name']._serialized_options = b'\272H\037\310\001\001r\032\020\001\030<2\024^[0-9a-z][0-9a-z-]*$\272J\001\002'
  _NETWORKINTERFACESPEC.fields_by_name['ip_address']._options = None
  _NETWORKINTERFACESPEC.fields_by_name['ip_address']._serialized_options = b'\272H\003\310\001\001\272J\002\006\002'
  _NETWORKINTERFACESPEC.fields_by_name['public_ip_address']._options = None
  _NETWORKINTERFACESPEC.fields_by_name['public_ip_address']._serialized_options = b'\272J\001\006'
  _IPALIAS.fields_by_name['allocation_id']._options = None
  _IPALIAS.fields_by_name['allocation_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_NETWORKINTERFACESPEC']._serialized_start=120
  _globals['_NETWORKINTERFACESPEC']._serialized_end=457
  _globals['_IPADDRESS']._serialized_start=459
  _globals['_IPADDRESS']._serialized_end=507
  _globals['_PUBLICIPADDRESS']._serialized_start=509
  _globals['_PUBLICIPADDRESS']._serialized_end=603
  _globals['_IPALIAS']._serialized_start=605
  _globals['_IPALIAS']._serialized_end=659
  _globals['_NETWORKINTERFACESTATUS']._serialized_start=662
  _globals['_NETWORKINTERFACESTATUS']._serialized_end=996
  _globals['_IPADDRESSSTATUS']._serialized_start=998
  _globals['_IPADDRESSSTATUS']._serialized_end=1078
  _globals['_PUBLICIPADDRESSSTATUS']._serialized_start=1080
  _globals['_PUBLICIPADDRESSSTATUS']._serialized_end=1190
  _globals['_IPALIASESSTATUS']._serialized_start=1192
  _globals['_IPALIASESSTATUS']._serialized_end=1231
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/route_table.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fnebius/vpc/v1/route_table.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a\x18nebius/annotations.proto\"\xb8\x01\n\nRouteTable\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.vpc.v1.RouteTableSpecR\x04spec\x12\x37\n\x06status\x18\x03 \x01(\x0b\x32\x1f.nebius.vpc.v1.RouteTableStatusR\x06status\";\n\x0eRouteTableSpec\x12)\n\nnetwork_id\x18\x01 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tnetworkId\"\xd9\x01\n\x10RouteTableStatus\x12;\n\x05state\x18\x01 \x01(\x0e\x32%.nebius.vpc.v1.RouteTableStatus.StateR\x05state\x12\x18\n\x07\x64\x65\x66\x61ult\x18\x02 \x01(\x08R\x07\x64\x65\x66\x61ult\x12\x43\n\nassignment\x18\x03 \x01(\x0b\x32#.nebius.vpc.v1.RouteTableAssignmentR\nassignment\")\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\t\n\x05READY\x10\n\"0\n\x14RouteTableAssignment\x12\x18\n\x07subnets\x18\x01 \x03(\tR\x07subnetsBV\n\x14\x61i.nebius.pub.vpc.v1B\x0fRouteTableProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.route_table_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\017RouteTableProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _ROUTETABLESPEC.fields_by_name['network_id']._options = None
  _ROUTETABLESPEC.fields_by_name['network_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _globals['_ROUTETABLE']._serialized_start=139
  _globals['_ROUTETABLE']._serialized_end=323
  _globals['_ROUTETABLESPEC']._serialized_start=325
  _globals['_ROUTETABLESPEC']._serialized_end=384
  _globals['_ROUTETABLESTATUS']._serialized_start=387
  _globals['_ROUTETABLESTATUS']._serialized_end=604
  _globals['_ROUTETABLESTATUS_STATE']._serialized_start=563
  _globals['_ROUTETABLESTATUS_STATE']._serialized_end=604
  _globals['_ROUTETABLEASSIGNMENT']._serialized_start=606
  _globals['_ROUTETABLEASSIGNMENT']._serialized_end=654
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Artifact(_message.Message):
    __slots__ = ["id", "name", "media_type", "digest", "size", "status", "type", "created_at", "updated_at", "tags"]
    class Status(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        STATUS_UNSPECIFIED: _ClassVar[Artifact.Status]
        ACTIVE: _ClassVar[Artifact.Status]
        DELETING: _ClassVar[Artifact.Status]
    STATUS_UNSPECIFIED: Artifact.Status
    ACTIVE: Artifact.Status
    DELETING: Artifact.Status
    class Type(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        BLOB: _ClassVar[Artifact.Type]
        MANIFEST: _ClassVar[Artifact.Type]
        DEB_PACKAGE: _ClassVar[Artifact.Type]
        MANIFEST_LIST: _ClassVar[Artifact.Type]
        RELEASE_INDEX: _ClassVar[Artifact.Type]
        PACKAGE_INDEX: _ClassVar[Artifact.Type]
        GZIPPED_PACKAGE_INDEX: _ClassVar[Artifact.Type]
    BLOB: Artifact.Type
    MANIFEST: Artifact.Type
    DEB_PACKAGE: Artifact.Type
    MANIFEST_LIST: Artifact.Type
    RELEASE_INDEX: Artifact.Type
    PACKAGE_INDEX: Artifact.Type
    GZIPPED_PACKAGE_INDEX: Artifact.Type
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    MEDIA_TYPE_FIELD_NUMBER: _ClassVar[int]
    DIGEST_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    media_type: str
    digest: str
    size: int
    status: Artifact.Status
    type: Artifact.Type
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    tags: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., media_type: _Optional[str] = ..., digest: _Optional[str] = ..., size: _Optional[int] = ..., status: _Optional[_Union[Artifact.Status, str]] = ..., type: _Optional[_Union[Artifact.Type, str]] = ..., created_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...



from abc import ABC, abstractmethod

MASK_STRING: str = "**"
MAX_VISIBLE_PAYLOAD_LENGTH: int = 15
NO_SIGNATURE: int = -1


class TokenVersion:
    def __init__(
        self,
        prefix: str,
        delimiter: str,
        signature_position: int,
        token_parts_count: int,
    ):
        self.prefix: str = prefix
        self.delimiter: str = delimiter
        self.signature_position: int = signature_position
        self.token_parts_count: int = token_parts_count


ACCESS_TOKEN_VERSIONS: dict[str, TokenVersion] = {
    "V0": TokenVersion(
        prefix="v0.",
        delimiter=".",
        signature_position=NO_SIGNATURE,
        token_parts_count=1,
    ),
    "NE1": TokenVersion(
        prefix="ne1", delimiter=".", signature_position=1, token_parts_count=2
    ),
}

CREDENTIALS_VERSIONS: dict[str, TokenVersion] = {
    **ACCESS_TOKEN_VERSIONS,
    "DE1": TokenVersion(
        prefix="nd1", delimiter=".", signature_position=1, token_parts_count=2
    ),
    "JWT": TokenVersion(
        prefix="eyJ", delimiter=".", signature_position=2, token_parts_count=3
    ),
}


class TokenSanitizer:
    def __init__(self, extractor: "TokenVersionExtractor") -> None:
        self.extractor: TokenVersionExtractor = extractor

    @staticmethod
    def access_token_sanitizer() -> "TokenSanitizer":
        return TokenSanitizer(DefaultTokenVersionExtractor(ACCESS_TOKEN_VERSIONS))

    @staticmethod
    def credentials_sanitizer() -> "TokenSanitizer":
        return TokenSanitizer(DefaultTokenVersionExtractor(CREDENTIALS_VERSIONS))

    def sanitize(self, token: str) -> str:
        if not token:
            return ""

        version, recognized = self.extractor.extract(token)
        if not recognized:
            return sanitize_unrecognized(token)

        token_parts: list[str] = token.split(version.delimiter)

        if version.signature_position == NO_SIGNATURE:
            return sanitize_no_signature(token, version.prefix)

        if len(token_parts) <= version.signature_position:
            return sanitize_unrecognized(token)

        token_parts[version.signature_position] = MASK_STRING
        return version.delimiter.join(token_parts)

    def is_supported(self, token: str) -> bool:
        version, recognized = self.extractor.extract(token)
        if not recognized:
            return False
        token_parts: list[str] = token.split(version.delimiter)
        return len(token_parts) >= version.token_parts_count


def sanitize_no_signature(token: str, prefix: str) -> str:
    payload: str = token[len(prefix) :]
    if len(payload) <= MAX_VISIBLE_PAYLOAD_LENGTH:
        return token
    return token[: MAX_VISIBLE_PAYLOAD_LENGTH + len(prefix)] + MASK_STRING


def sanitize_unrecognized(token: str) -> str:
    if len(token) <= MAX_VISIBLE_PAYLOAD_LENGTH:
        return token + MASK_STRING
    return token[:MAX_VISIBLE_PAYLOAD_LENGTH] + MASK_STRING


class TokenVersionExtractor(ABC):
    @abstractmethod
    def extract(self, token: str) -> tuple[TokenVersion, bool]: ...


class DefaultTokenVersionExtractor(TokenVersionExtractor):
    def __init__(self, versions: dict[str, TokenVersion]) -> None:
        self.versions: dict[str, TokenVersion] = versions

    def extract(self, token: str) -> tuple[TokenVersion, bool]:
        for version in self.versions.values():
            if token.startswith(version.prefix):
                return version, True
        return TokenVersion("", "", NO_SIGNATURE, 0), False



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as _operation_pb2
from nebius.api.nebius.msp.postgresql.v1alpha1 import backup_pb2 as _backup_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetBackupRequest(_message.Message):
    __slots__ = ["cluster_id", "backup_id"]
    CLUSTER_ID_FIELD_NUMBER: _ClassVar[int]
    BACKUP_ID_FIELD_NUMBER: _ClassVar[int]
    cluster_id: str
    backup_id: str
    def __init__(self, cluster_id: _Optional[str] = ..., backup_id: _Optional[str] = ...) -> None: ...

class ListBackupsRequest(_message.Message):
    __slots__ = ["parent_id"]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    parent_id: str
    def __init__(self, parent_id: _Optional[str] = ...) -> None: ...

class ListBackupsByClusterRequest(_message.Message):
    __slots__ = ["cluster_id"]
    CLUSTER_ID_FIELD_NUMBER: _ClassVar[int]
    cluster_id: str
    def __init__(self, cluster_id: _Optional[str] = ...) -> None: ...

class ListBackupsResponse(_message.Message):
    __slots__ = ["backups"]
    BACKUPS_FIELD_NUMBER: _ClassVar[int]
    backups: _containers.RepeatedCompositeFieldContainer[_backup_pb2.Backup]
    def __init__(self, backups: _Optional[_Iterable[_Union[_backup_pb2.Backup, _Mapping]]] = ...) -> None: ...

class CreateBackupRequest(_message.Message):
    __slots__ = ["cluster_id"]
    CLUSTER_ID_FIELD_NUMBER: _ClassVar[int]
    cluster_id: str
    def __init__(self, cluster_id: _Optional[str] = ...) -> None: ...

class DeleteBackupRequest(_message.Message):
    __slots__ = ["cluster_id", "backup_id"]
    CLUSTER_ID_FIELD_NUMBER: _ClassVar[int]
    BACKUP_ID_FIELD_NUMBER: _ClassVar[int]
    cluster_id: str
    backup_id: str
    def __init__(self, cluster_id: _Optional[str] = ..., backup_id: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/vpc/v1/target_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.vpc.v1 import target_group_pb2 as nebius_dot_vpc_dot_v1_dot_target__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/vpc/v1/target_group_service.proto\x12\rnebius.vpc.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a nebius/vpc/v1/target_group.proto\"/\n\x15GetTargetGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\xd8\x02\n\x18UpdateTargetGroupRequest\x12\x87\x02\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\xc6\x01\xbaH\xc2\x01\xba\x01\xbe\x01\n\rmetadata_name\x12s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\x1a\x38this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')R\x08metadata\x12\x32\n\x04spec\x18\x02 \x01(\x0b\x32\x1e.nebius.vpc.v1.TargetGroupSpecR\x04spec2\xb5\x01\n\x12TargetGroupService\x12G\n\x03Get\x12$.nebius.vpc.v1.GetTargetGroupRequest\x1a\x1a.nebius.vpc.v1.TargetGroup\x12N\n\x06Update\x12\'.nebius.vpc.v1.UpdateTargetGroupRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x06\xbaJ\x03vpcB^\n\x14\x61i.nebius.pub.vpc.v1B\x17TargetGroupServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/vpc/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.vpc.v1.target_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.vpc.v1B\027TargetGroupServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/vpc/v1'
  _GETTARGETGROUPREQUEST.fields_by_name['id']._options = None
  _GETTARGETGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATETARGETGROUPREQUEST.fields_by_name['metadata']._options = None
  _UPDATETARGETGROUPREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\302\001\272\001\276\001\n\rmetadata_name\022s\'name\' must start with a letter or digit, allow \'-\', \'_\', \'.\', \'/\', and have a length between 2 and 255 characters.\0328this.name.matches(\'^[a-zA-Z0-9][-_./a-zA-Z0-9]{1,254}$\')'
  _TARGETGROUPSERVICE._options = None
  _TARGETGROUPSERVICE._serialized_options = b'\272J\003vpc'
  _globals['_GETTARGETGROUPREQUEST']._serialized_start=215
  _globals['_GETTARGETGROUPREQUEST']._serialized_end=262
  _globals['_UPDATETARGETGROUPREQUEST']._serialized_start=265
  _globals['_UPDATETARGETGROUPREQUEST']._serialized_end=609
  _globals['_TARGETGROUPSERVICE']._serialized_start=612
  _globals['_TARGETGROUPSERVICE']._serialized_end=793
# @@protoc_insertion_point(module_scope)



"""Service-account based bearer for asynchronous authentication.

- This module provides a convenience :class:`ServiceAccountBearer` which
- composes several internal bearer implementations to support exchanging
- service account credentials for access tokens, automatic renewal and a
- stable diagnostic name.

- The bearer may be constructed from one of three inputs:
    - a :class:`nebius.base.service_account.service_account.Reader` instance
        which will be used to read the actual
        :class:`nebius.base.service_account.service_account.ServiceAccount`;
- a ready-made :class:`nebius.base.service_account.service_account.ServiceAccount`;
- a string service account id together with ``private_key`` and ``public_key_id``
  which will be used to build an in-memory :class:`ServiceAccount`.

Examples
Constructing from an environment/CLI-backed reader (recommended):

>>> from nebius.aio.token.service_account import ServiceAccountBearer
>>> from nebius.base.service_account.pk_file import Reader as PKReader
>>> bearer = ServiceAccountBearer(PKReader("/path/to/private_key.pem"))

Constructing from explicit values (private key object required):

>>> from cryptography.hazmat.primitives.serialization import load_pem_private_key
>>> from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey
>>> with open("/path/to/private_key.pem","rb") as fh:
...     key = load_pem_private_key(fh.read(), password=None)
>>> bearer = ServiceAccountBearer(
...     "service-account-id",
...     private_key=key,  # type: RSAPrivateKey
...     public_key_id="public-key-id",
... )

The resulting bearer exposes the :meth:`receiver` method used by the SDK's
authentication layer. See :mod:`nebius.aio.token.token` for the receiver and
token abstractions.
"""

from datetime import timedelta

from cryptography.hazmat.primitives.asymmetric.rsa import RSAPrivateKey

from nebius.aio.abc import ClientChannelInterface
from nebius.aio.token.deferred_channel import DeferredChannel
from nebius.aio.token.exchangeable import Bearer as ExchangeableBearer
from nebius.aio.token.renewable import Bearer as RenewableBearer
from nebius.aio.token.token import Bearer as ParentBearer
from nebius.aio.token.token import NamedBearer, Receiver
from nebius.base.service_account.service_account import (
    Reader as ServiceAccountReader,
)
from nebius.base.service_account.service_account import (
    ServiceAccount,
)
from nebius.base.service_account.static import Reader as ServiceAccountReaderStatic


class ServiceAccountBearer(ParentBearer):
    """Bearer that obtains tokens using a service account.

    The class composes an exchangeable bearer (that performs the token
    exchange), wraps it into a renewable bearer (to handle background token
    refresh) and finally assigns a stable ``name`` using :class:`NamedBearer`.

    The chain from the outermost to innermost is as follows:

      * :class:`NamedBearer` ->
      * :class:`RenewableBearer` ->
      * :class:`ExchangeableBearer` ->
      * :class:`ServiceAccountReader` ->
      * :class:`ServiceAccount`

    :param service_account: Service account credentials used to obtain tokens.
        May be a :class:`ServiceAccountReader`, a :class:`ServiceAccount` or a
        string service account id.
    :param channel: A channel used to perform the token exchange. This channel must
        be provided before any token fetch operation, or a :class:`DeferredChannel`
        may be used to set the channel asynchronously. If neither is provided,
        token fetch operations will fail until :meth:`set_channel` is called.
    :param private_key: When ``service_account`` is a string id, this private key
        is used to sign token exchange requests. Must not be provided if the service
        account is provided as a :class:`ServiceAccount` or
        :class:`ServiceAccountReader`.
    :param public_key_id: When ``service_account`` is a string id, this is the
        public key ID corresponding to the private key. Must not be provided if the
        service account is provided as a :class:`ServiceAccount` or
        :class:`ServiceAccountReader`.
    :param max_retries: Maximum number of retries for token fetch operations.
    :param lifetime_safe_fraction: Fraction of token lifetime considered safe
        to use before triggering a refresh.
    :param initial_retry_timeout: Initial delay between retry attempts for
        refresh operations.
    :param max_retry_timeout: Maximum delay between retry attempts for
        refresh operations.
    :param retry_timeout_exponent: Exponential backoff exponent for retry
        delays.
    :param refresh_request_timeout: Timeout for individual token refresh
        requests.

    Example
    -------

    Construct a bearer and use it to initialize the SDK::

        from asyncio import Future
        from nebius.sdk import SDK
        from nebius.aio.token.service_account import ServiceAccountBearer
        from cryptography.hazmat.primitives.serialization import load_pem_private_key

        with open("/path/to/private_key.pem", "rb") as fh:
            private_key = load_pem_private_key(fh.read(), password=None)

        # Create a future for the channel that will be resolved with the SDK
        channel_future = Future()

        sdk = SDK(credentials=ServiceAccountBearer(
            "service-account-id",
            private_key=private_key,
            public_key_id="public-key-id",
            channel=channel_future,
        ))

        # Resolve the future with the newly created SDK
        channel_future.set_result(sdk)
    """

    def __init__(
        self,
        service_account: ServiceAccountReader | ServiceAccount | str,
        channel: ClientChannelInterface | DeferredChannel | None = None,
        private_key: RSAPrivateKey | None = None,
        public_key_id: str | None = None,
        max_retries: int = 2,
        lifetime_safe_fraction: float = 0.9,
        initial_retry_timeout: timedelta = timedelta(seconds=1),
        max_retry_timeout: timedelta = timedelta(minutes=1),
        retry_timeout_exponent: float = 1.5,
        refresh_request_timeout: timedelta = timedelta(seconds=5),
    ) -> None:
        """Initialize a service-account based bearer.

        This is essentially a convenience wrapper that composes several
        internal bearer implementations to provide a ready-to-use bearer
        that fetches tokens using service account credentials and is being conveniently
        named with the service account parameters.

        **Important note:**
        When constructing the bearer using a dynamic :class:`ServiceAccountReader`,
        the name of the bearer will reflect the service account as read during
        construction time. If the reader returns different service accounts
        on subsequent reads, the name will not reflect those changes.
        """
        reader: ServiceAccountReader | None = None
        if isinstance(service_account, ServiceAccountReader):
            reader = service_account
            service_account = service_account.read()
        if isinstance(service_account, str):
            if not isinstance(private_key, RSAPrivateKey):
                raise TypeError(
                    "Private key must be provided as RSAPrivateKey instance "
                    "when service_account is a string."
                )
            if not isinstance(public_key_id, str):
                raise TypeError(
                    "Public key ID must be provided as a string when service_account "
                    "is a string."
                )
            service_account = ServiceAccount(
                private_key=private_key,
                public_key_id=public_key_id,
                service_account_id=service_account,
            )
        else:
            if private_key is not None or public_key_id is not None:
                raise ValueError(
                    "Private key and public key ID must not be provided "
                    "when service_account is a ServiceAccount or ServiceAccountReader "
                    "instance."
                )
        if not isinstance(service_account, ServiceAccount):  # type: ignore[unused-ignore]
            raise TypeError(
                "service_account must be ServiceAccountReader, ServiceAccount or string"
                f", got {type(service_account)}"
            )
        if reader is None:
            reader = ServiceAccountReaderStatic(service_account)
        sa_id = service_account.service_account_id
        public_key_id = service_account.public_key_id
        private_key = service_account.private_key

        self._exchangeable = ExchangeableBearer(
            reader,
            channel=channel,
            max_retries=max_retries,
        )

        self._source = NamedBearer(
            RenewableBearer(
                self._exchangeable,
                max_retries=max_retries,
                lifetime_safe_fraction=lifetime_safe_fraction,
                initial_retry_timeout=initial_retry_timeout,
                max_retry_timeout=max_retry_timeout,
                retry_timeout_exponent=retry_timeout_exponent,
                refresh_request_timeout=refresh_request_timeout,
            ),
            f"service-account/{sa_id}/{public_key_id}",
        )

    def set_channel(self, channel: ClientChannelInterface) -> None:
        """Attach a concrete channel to the exchangeable bearer.

        This function must be used when a channel was not available at construction
        and a :class:`DeferredChannel` was not provided.

        :param channel: The concrete channel to attach.
        :type channel: :class:`ClientChannelInterface`
        """
        self._exchangeable.set_channel(channel)

    @property
    def wrapped(self) -> "ParentBearer|None":
        """Returns the outermost underlying bearer :class:`NamedBearer`."""
        return self._source

    def receiver(self) -> "Receiver":
        """Calls the receiver of the underlying bearer :class:`NamedBearer`."""
        return self._source.receiver()



from nebius.api.nebius.compute.v1 import disk_service_pb2 as _disk_service_pb2
from nebius.api.nebius.compute.v1 import filesystem_service_pb2 as _filesystem_service_pb2
from nebius.api.nebius.compute.v1 import instance_service_pb2 as _instance_service_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ResourceSpec(_message.Message):
    __slots__ = ["compute_instance_spec", "compute_instance_update_spec", "compute_disk_spec", "compute_disk_update_spec", "compute_filesystem_spec", "compute_filesystem_update_spec"]
    COMPUTE_INSTANCE_SPEC_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_INSTANCE_UPDATE_SPEC_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_DISK_SPEC_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_DISK_UPDATE_SPEC_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_FILESYSTEM_SPEC_FIELD_NUMBER: _ClassVar[int]
    COMPUTE_FILESYSTEM_UPDATE_SPEC_FIELD_NUMBER: _ClassVar[int]
    compute_instance_spec: _instance_service_pb2.CreateInstanceRequest
    compute_instance_update_spec: _instance_service_pb2.UpdateInstanceRequest
    compute_disk_spec: _disk_service_pb2.CreateDiskRequest
    compute_disk_update_spec: _disk_service_pb2.UpdateDiskRequest
    compute_filesystem_spec: _filesystem_service_pb2.CreateFilesystemRequest
    compute_filesystem_update_spec: _filesystem_service_pb2.UpdateFilesystemRequest
    def __init__(self, compute_instance_spec: _Optional[_Union[_instance_service_pb2.CreateInstanceRequest, _Mapping]] = ..., compute_instance_update_spec: _Optional[_Union[_instance_service_pb2.UpdateInstanceRequest, _Mapping]] = ..., compute_disk_spec: _Optional[_Union[_disk_service_pb2.CreateDiskRequest, _Mapping]] = ..., compute_disk_update_spec: _Optional[_Union[_disk_service_pb2.UpdateDiskRequest, _Mapping]] = ..., compute_filesystem_spec: _Optional[_Union[_filesystem_service_pb2.CreateFilesystemRequest, _Mapping]] = ..., compute_filesystem_update_spec: _Optional[_Union[_filesystem_service_pb2.UpdateFilesystemRequest, _Mapping]] = ...) -> None: ...

class ResourceGroupCost(_message.Message):
    __slots__ = ["general"]
    GENERAL_FIELD_NUMBER: _ClassVar[int]
    general: GeneralTotalCost
    def __init__(self, general: _Optional[_Union[GeneralTotalCost, _Mapping]] = ...) -> None: ...

class GeneralTotalCost(_message.Message):
    __slots__ = ["total"]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    total: CostBreakdown
    def __init__(self, total: _Optional[_Union[CostBreakdown, _Mapping]] = ...) -> None: ...

class GeneralResourceCost(_message.Message):
    __slots__ = ["total"]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    total: CostBreakdown
    def __init__(self, total: _Optional[_Union[CostBreakdown, _Mapping]] = ...) -> None: ...

class CostBreakdown(_message.Message):
    __slots__ = ["cost", "cost_rounded"]
    COST_FIELD_NUMBER: _ClassVar[int]
    COST_ROUNDED_FIELD_NUMBER: _ClassVar[int]
    cost: str
    cost_rounded: str
    def __init__(self, cost: _Optional[str] = ..., cost_rounded: _Optional[str] = ...) -> None: ...



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius import annotations_pb2 as _annotations_pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as _metadata_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Group(_message.Message):
    __slots__ = ["metadata", "spec", "status"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    SPEC_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    metadata: _metadata_pb2.ResourceMetadata
    spec: GroupSpec
    status: GroupStatus
    def __init__(self, metadata: _Optional[_Union[_metadata_pb2.ResourceMetadata, _Mapping]] = ..., spec: _Optional[_Union[GroupSpec, _Mapping]] = ..., status: _Optional[_Union[GroupStatus, _Mapping]] = ...) -> None: ...

class GroupSpec(_message.Message):
    __slots__ = []
    def __init__(self) -> None: ...

class GroupStatus(_message.Message):
    __slots__ = ["state", "members_count", "service_accounts_count", "tenant_user_accounts_count"]
    class State(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = []
        UNSPECIFIED: _ClassVar[GroupStatus.State]
        ACTIVE: _ClassVar[GroupStatus.State]
    UNSPECIFIED: GroupStatus.State
    ACTIVE: GroupStatus.State
    STATE_FIELD_NUMBER: _ClassVar[int]
    MEMBERS_COUNT_FIELD_NUMBER: _ClassVar[int]
    SERVICE_ACCOUNTS_COUNT_FIELD_NUMBER: _ClassVar[int]
    TENANT_USER_ACCOUNTS_COUNT_FIELD_NUMBER: _ClassVar[int]
    state: GroupStatus.State
    members_count: int
    service_accounts_count: int
    tenant_user_accounts_count: int
    def __init__(self, state: _Optional[_Union[GroupStatus.State, str]] = ..., members_count: _Optional[int] = ..., service_accounts_count: _Optional[int] = ..., tenant_user_accounts_count: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/serverless/v1alpha1/job.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.msp.v1alpha1 import cluster_pb2 as nebius_dot_msp_dot_v1alpha1_dot_cluster__pb2
from nebius.api.nebius.msp.v1alpha1.resource import template_pb2 as nebius_dot_msp_dot_v1alpha1_dot_resource_dot_template__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(nebius/msp/serverless/v1alpha1/job.proto\x12\x1enebius.msp.serverless.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a!nebius/msp/v1alpha1/cluster.proto\x1a+nebius/msp/v1alpha1/resource/template.proto\"\xdb\x01\n\x03Job\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x43\n\x04spec\x18\x02 \x01(\x0b\x32\'.nebius.msp.serverless.v1alpha1.JobSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12G\n\x06status\x18\x03 \x01(\x0b\x32).nebius.msp.serverless.v1alpha1.JobStatusB\x04\xbaJ\x01\x05R\x06status\"\xa6\x01\n\x07JobSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12)\n\nnetwork_id\x18\x02 \x01(\tB\n\xbaH\x03\xc8\x01\x01\xbaJ\x01\x02R\tnetworkId\x12N\n\tcontainer\x18\x65 \x01(\x0b\x32\x30.nebius.msp.serverless.v1alpha1.JobContainerSpecR\tcontainer\"\xe4\x04\n\x10JobContainerSpec\x12\x1c\n\x05image\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05image\x12#\n\rreplica_count\x18\x02 \x01(\x03R\x0creplicaCount\x12S\n\x08template\x18\x03 \x01(\x0b\x32/.nebius.msp.serverless.v1alpha1.JobTemplateSpecB\x06\xbaH\x03\xc8\x01\x01R\x08template\x12\x18\n\x07\x63ommand\x18\x65 \x01(\tR\x07\x63ommand\x12\x12\n\x04\x61rgs\x18\x66 \x03(\tR\x04\x61rgs\x12N\n\x04\x65nvs\x18g \x03(\x0b\x32:.nebius.msp.serverless.v1alpha1.JobContainerSpec.EnvsEntryR\x04\x65nvs\x12s\n\x0esensitive_envs\x18h \x03(\x0b\x32\x43.nebius.msp.serverless.v1alpha1.JobContainerSpec.SensitiveEnvsEntryB\x07\xbaJ\x01\x04\xc0J\x01R\rsensitiveEnvs\x12(\n\x0ftimeout_seconds\x18\xc9\x01 \x01(\x03R\x0etimeoutSeconds\x12 \n\x0bmax_retries\x18\xca\x01 \x01(\x03R\nmaxRetries\x1a\x37\n\tEnvsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a@\n\x12SensitiveEnvsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"d\n\x0fJobTemplateSpec\x12Q\n\tresources\x18\x01 \x01(\x0b\x32+.nebius.msp.v1alpha1.resource.ResourcesSpecB\x06\xbaH\x03\xc8\x01\x01R\tresources\"\xce\x01\n\tJobStatus\x12>\n\x05phase\x18\x01 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.PhaseR\x05phase\x12>\n\x05state\x18\x02 \x01(\x0e\x32(.nebius.msp.v1alpha1.ClusterStatus.StateR\x05state\x12\x41\n\x06result\x18\x03 \x01(\x0e\x32).nebius.msp.serverless.v1alpha1.JobResultR\x06result*q\n\tJobResult\x12\x1a\n\x16JOB_RESULT_UNSPECIFIED\x10\x00\x12\x16\n\x12JOB_RESULT_SUCCESS\x10\x01\x12\x16\n\x12JOB_RESULT_FAILURE\x10\x02\x12\x18\n\x14JOB_RESULT_CANCELLED\x10\x03\x42q\n%ai.nebius.pub.msp.serverless.v1alpha1B\x08JobProtoP\x01Z<github.com/nebius/gosdk/proto/nebius/msp/serverless/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.serverless.v1alpha1.job_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%ai.nebius.pub.msp.serverless.v1alpha1B\010JobProtoP\001Z<github.com/nebius/gosdk/proto/nebius/msp/serverless/v1alpha1'
  _JOB.fields_by_name['metadata']._options = None
  _JOB.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _JOB.fields_by_name['spec']._options = None
  _JOB.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _JOB.fields_by_name['status']._options = None
  _JOB.fields_by_name['status']._serialized_options = b'\272J\001\005'
  _JOBSPEC.fields_by_name['network_id']._options = None
  _JOBSPEC.fields_by_name['network_id']._serialized_options = b'\272H\003\310\001\001\272J\001\002'
  _JOBCONTAINERSPEC_ENVSENTRY._options = None
  _JOBCONTAINERSPEC_ENVSENTRY._serialized_options = b'8\001'
  _JOBCONTAINERSPEC_SENSITIVEENVSENTRY._options = None
  _JOBCONTAINERSPEC_SENSITIVEENVSENTRY._serialized_options = b'8\001'
  _JOBCONTAINERSPEC.fields_by_name['image']._options = None
  _JOBCONTAINERSPEC.fields_by_name['image']._serialized_options = b'\272H\003\310\001\001'
  _JOBCONTAINERSPEC.fields_by_name['template']._options = None
  _JOBCONTAINERSPEC.fields_by_name['template']._serialized_options = b'\272H\003\310\001\001'
  _JOBCONTAINERSPEC.fields_by_name['sensitive_envs']._options = None
  _JOBCONTAINERSPEC.fields_by_name['sensitive_envs']._serialized_options = b'\272J\001\004\300J\001'
  _JOBTEMPLATESPEC.fields_by_name['resources']._options = None
  _JOBTEMPLATESPEC.fields_by_name['resources']._serialized_options = b'\272H\003\310\001\001'
  _globals['_JOBRESULT']._serialized_start=1561
  _globals['_JOBRESULT']._serialized_end=1674
  _globals['_JOB']._serialized_start=245
  _globals['_JOB']._serialized_end=464
  _globals['_JOBSPEC']._serialized_start=467
  _globals['_JOBSPEC']._serialized_end=633
  _globals['_JOBCONTAINERSPEC']._serialized_start=636
  _globals['_JOBCONTAINERSPEC']._serialized_end=1248
  _globals['_JOBCONTAINERSPEC_ENVSENTRY']._serialized_start=1127
  _globals['_JOBCONTAINERSPEC_ENVSENTRY']._serialized_end=1182
  _globals['_JOBCONTAINERSPEC_SENSITIVEENVSENTRY']._serialized_start=1184
  _globals['_JOBCONTAINERSPEC_SENSITIVEENVSENTRY']._serialized_end=1248
  _globals['_JOBTEMPLATESPEC']._serialized_start=1250
  _globals['_JOBTEMPLATESPEC']._serialized_end=1350
  _globals['_JOBSTATUS']._serialized_start=1353
  _globals['_JOBSTATUS']._serialized_end=1559
# @@protoc_insertion_point(module_scope)
